@@ -24,9 +24,6 @@
 
 #include <config.h>
 
-#include <sys/types.h>
-
-#include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
 
