@@ -23,12 +23,7 @@
 #include <sys/wait.h>
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef HAVE_STRING_H
-# include <string.h>
-#endif /* HAVE_STRING_H */
-#ifdef HAVE_STRINGS_H
-# include <strings.h>
-#endif /* HAVE_STRINGS_H */
+#include <string.h>
 #ifdef HAVE_STDBOOL_H
 # include <stdbool.h>
 #else
@@ -87,7 +82,7 @@ runtests(char **buf, size_t *buflen)
 		sudo_warn_nodebug("send");
 		_exit(127);
 	    }
-	    _exit(0);
+	    _exit(EXIT_SUCCESS);
 	    break;
 	default:
 	    /* parent */
