@@ -23,20 +23,8 @@
 
 #include <config.h>
 
-#include <sys/types.h>
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef HAVE_STRING_H
-# include <string.h>
-#endif /* HAVE_STRING_H */
-#ifdef HAVE_STRINGS_H
-# include <strings.h>
-#endif /* HAVE_STRINGS_H */
-#include <unistd.h>
-#include <ctype.h>
-#include <grp.h>
-#include <pwd.h>
-#include <time.h>
 
 #include "sudoers.h"
 #include "parse.h"
