@@ -25,19 +25,14 @@
 
 #include <config.h>
 
-#include <sys/types.h>
 #include <sys/time.h>
-#include <sys/stat.h>
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef HAVE_STRING_H
-# include <string.h>
-#endif /* HAVE_STRING_H */
+#include <string.h>
 #ifdef HAVE_STRINGS_H
 # include <strings.h>
 #endif /* HAVE_STRINGS_H */
 #include <unistd.h>
-#include <time.h>
 #include <ctype.h>
 #include <fcntl.h>
 #ifdef HAVE_LBER_H
