@@ -41,12 +41,7 @@
 #ifdef HAVE_SPAWN_H
 #include <spawn.h>
 #endif
-#ifdef HAVE_STRING_H
-# include <string.h>
-#endif /* HAVE_STRING_H */
-#ifdef HAVE_STRINGS_H
-# include <strings.h>
-#endif /* HAVE_STRINGS_H */
+#include <string.h>
 #ifdef HAVE_WORDEXP_H
 #include <wordexp.h>
 #endif
